@@ -216,7 +216,7 @@ static int sync_session(void *data, struct session_info *info)
 				  iscsi_err_to_str(err));
 			return 0;
 		}
-		iscsi_sysfs_scan_host(host_no, 0);
+		iscsi_sysfs_scan_host(host_no, 0, idbm_session_autoscan(NULL));
 		return 0;
 	}
 
@@ -274,7 +274,7 @@ static int sync_session(void *data, struct session_info *info)
 	memcpy(&req.u.session.rec, &rec, sizeof(node_rec_t));
 
 retry:
-	rc = iscsid_exec_req(&req, &rsp, 0);
+	rc = iscsid_exec_req(&req, &rsp, 0, info->iscsid_req_tmo);
 	if (rc == ISCSI_ERR_ISCSID_NOTCONN && retries < 30) {
 		retries++;
 		sleep(1);
@@ -313,8 +313,7 @@ static void catch_signal(int signo)
 
 	switch (signo) {
 	case SIGTERM:
-		iscsid_shutdown();
-		exit(0);
+		event_loop_exit(NULL);
 		break;
 	default:
 		break;
